#!/bin/sh

## Copyright (C) 2012 - 2023 ENCRYPTED SUPPORT LP <adrelanos@whonix.org>
## See the file COPYING for copying conditions.

if test -f /usr/share/qubes/marker-vm ; then
   true "$0: Not running in Qubes, not doing anything."
   return 0
   exit 0
fi

if command -v systemd-detect-virt >/dev/null ; then
   result="$(systemd-detect-virt)"
else
   true "$0: systemd-detect-virt not found. Stop."
   return 0
   exit 0
fi

if [ "$result" = "" ]; then
   true "$0: Not running in a Virtual Machine (or none detected), therefore not disabling monitor power saving. Stop."
   return 0
   exit 0
else
   true "$0: VM $result found. Continue."
fi

if [ -z "$XDG_CONFIG_DIRS" ]; then
   XDG_CONFIG_DIRS=/etc/xdg
fi
export XDG_CONFIG_DIRS=/usr/share/kde-power-savings-disable-in-vms/:$XDG_CONFIG_DIRS

xset_command_exit_code="0"
command -v xset >/dev/null || { xset_command_exit_code="$?" ; true; };

if [ ! "$xset_command_exit_code" = "0" ]; then
   true "$0: xset not installed. Stop."
   return 0
   exit 0
else
   true "$0: xset found. Continue."
fi

(
   if [ "$(id -u)" = "0" ]; then
      true "$0: Can not run as root. Exiting."
      exit 0
   fi
   sleep 60 &
   wait "$!"
   xset s off
   true "$0: exit code: $?"
   xset -dpms
   true "$0: exit code: $?"
   exit 0
) &

return 0
exit 0
