#!/bin/sh

## Copyright (C) 2020 - 2023 ENCRYPTED SUPPORT LP <adrelanos@whonix.org>
## See the file COPYING for copying conditions.

if command -v systemd-detect-virt >/dev/null ; then
   result="$(systemd-detect-virt)"
   ## result example:
   ## oracle
else
   echo "$0 ERROR: systemd-detect-virt not found. Stop."
   return 0
   exit 0
fi

if [ "$result" = "oracle" ]; then
   software_rendering_use=true
fi

if [ "$result" = "kvm" ]; then
   software_rendering_use=true
fi

if [ "$result" = "xen" ]; then
   software_rendering_use=true
fi

if [ ! "$software_rendering_use" = "true" ]; then
   return 0
   exit 0
fi

if [ "$QMLSCENE_DEVICE" = "" ]; then
   ## useful for:
   ## - signal-desktop
   ## - maybe also wire-desktop?
   ##
   ## Automatic fallback to softwarecontext renderer
   ##
   ## Not great to set this unconditionally in VirtualBox but there is no known
   ## tool which can find out from inside the VM if VirtualBox 3D acceleration
   ## is enabled from inside the VM, see:
   ## Test command from inside VM to detect if VirtualBox 3D acceleration is enabled or disabled?
   ## https://forums.virtualbox.org/viewtopic.php?f=3&t=97983
   export QMLSCENE_DEVICE=softwarecontext
fi

return 0
exit 0
